package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.BaseFactoryInfo;
import com.ruoyi.system.service.IBaseFactoryInfoService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 工厂信息Controller
 * 
 * @author ruoyi
 * @date 2024-07-01
 */
@RestController
@RequestMapping("/info")
public class BaseFactoryInfoController extends BaseController
{
    @Autowired
    private IBaseFactoryInfoService baseFactoryInfoService;

    /**
     * 查询工厂信息列表
     */
    @RequiresPermissions("system:info:list")
    @GetMapping("/list")
    public TableDataInfo list(BaseFactoryInfo baseFactoryInfo)
    {
        startPage();
        List<BaseFactoryInfo> list = baseFactoryInfoService.selectBaseFactoryInfoList(baseFactoryInfo);
        return getDataTable(list);
    }

    /**
     * 导出工厂信息列表
     */
    @RequiresPermissions("system:info:export")
    @Log(title = "工厂信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseFactoryInfo baseFactoryInfo)
    {
        List<BaseFactoryInfo> list = baseFactoryInfoService.selectBaseFactoryInfoList(baseFactoryInfo);
        ExcelUtil<BaseFactoryInfo> util = new ExcelUtil<BaseFactoryInfo>(BaseFactoryInfo.class);
        util.exportExcel(response, list, "工厂信息数据");
    }

    /**
     * 获取工厂信息详细信息
     */
    @RequiresPermissions("system:info:query")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId)
    {
        return success(baseFactoryInfoService.selectBaseFactoryInfoByObjId(objId));
    }

    /**
     * 新增工厂信息
     */
    @RequiresPermissions("system:info:add")
    @Log(title = "工厂信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseFactoryInfo baseFactoryInfo)
    {
        return toAjax(baseFactoryInfoService.insertBaseFactoryInfo(baseFactoryInfo));
    }

    /**
     * 修改工厂信息
     */
    @RequiresPermissions("system:info:edit")
    @Log(title = "工厂信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseFactoryInfo baseFactoryInfo)
    {
        return toAjax(baseFactoryInfoService.updateBaseFactoryInfo(baseFactoryInfo));
    }

    /**
     * 删除工厂信息
     */
    @RequiresPermissions("system:info:remove")
    @Log(title = "工厂信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds)
    {
        return toAjax(baseFactoryInfoService.deleteBaseFactoryInfoByObjIds(objIds));
    }
}
