package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.utils.uuid.UUID;
import com.ruoyi.system.api.domain.SysUser;
import com.ruoyi.system.domain.SysUserDatasource;
import com.ruoyi.system.service.ISysUserDatasourceService;
import com.ruoyi.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.SysDatasource;
import com.ruoyi.system.service.ISysDatasourceService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 数据管理Controller
 * 
 * @author ruoyi
 * @date 2023-07-03
 */
@RestController
@RequestMapping("/datasource")
public class SysDatasourceController extends BaseController
{
    @Autowired
    private ISysDatasourceService sysDatasourceService;

    @Autowired
    private ISysUserDatasourceService sysUserDatasourceService;

    @Autowired
    private ISysUserService userService;

    /**
     * 查询数据管理列表
     */
    @RequiresPermissions("system:datasource:list")
    @GetMapping("/list")
    public TableDataInfo list(SysDatasource sysDatasource)
    {
        startPage();
        List<SysDatasource> list = sysDatasourceService.selectSysDatasourceList(sysDatasource);
        return getDataTable(list);
    }

    /**
     * 导出数据管理列表
     */
    @RequiresPermissions("system:datasource:export")
    @Log(title = "数据管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysDatasource sysDatasource)
    {
        List<SysDatasource> list = sysDatasourceService.selectSysDatasourceList(sysDatasource);
        ExcelUtil<SysDatasource> util = new ExcelUtil<SysDatasource>(SysDatasource.class);
        util.exportExcel(response, list, "数据管理数据");
    }

    /**
     * 获取数据管理详细信息
     */
    @RequiresPermissions("system:datasource:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(sysDatasourceService.selectSysDatasourceById(id));
    }

    /**
     * 新增数据管理
     */
    @RequiresPermissions("system:datasource:add")
    @Log(title = "数据管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysDatasource sysDatasource)
    {
        UUID uuid = UUID.randomUUID();
        sysDatasource.setId(uuid.toString());
        //将数据源分配给管理员
        AddUserDataSource(sysDatasource);
        return toAjax(sysDatasourceService.insertSysDatasource(sysDatasource));
    }

    /**
     * 修改数据管理
     */
    @RequiresPermissions("system:datasource:edit")
    @Log(title = "数据管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysDatasource sysDatasource)
    {
        return toAjax(sysDatasourceService.updateSysDatasource(sysDatasource));
    }

    /**
     * 删除数据管理
     */
    @RequiresPermissions("system:datasource:remove")
    @Log(title = "数据管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        //删除已经分配的数据源
        DeleteUserDataSource(ids);
        return toAjax(sysDatasourceService.deleteSysDatasourceByIds(ids));
    }

    /**
     * 每次增加数据源均分配给超级管理员
     * @param sysDatasource
     */
    public void AddUserDataSource(SysDatasource sysDatasource){

        try{
            SysUser sysUser = userService.selectUserByUserName("admin");
            SysUserDatasource sysUserDatasource = new SysUserDatasource();
            sysUserDatasource.setUserId(sysUser.getUserId().toString());
            sysUserDatasource.setDatasourceId(sysDatasource.getId());
            int i = sysUserDatasourceService.insertSysUserDatasource(sysUserDatasource);
            if(i>0){
                logger.info("数据源："+sysDatasource.getParkName()+"；分配成功！");
            }else {
                logger.info("数据源："+sysDatasource.getParkName()+"；分配成功！");
            }
        }catch (Exception ex){
            logger.error("数据源分配异常:"+ex.getMessage());
        }
    }

    /**
     * 删除绑定信息
     * @param ids
     */
    public void  DeleteUserDataSource(String[] ids){
        try{
            for (String id : ids) {
                SysUserDatasource sysUserDatasource = new SysUserDatasource();
                sysUserDatasource.setDatasourceId(id);
                List<SysUserDatasource> sysUserDatasources = sysUserDatasourceService.selectSysUserDatasourceList(sysUserDatasource);
                if(sysUserDatasources.size() > 0){
                    Long[] ageArray = sysUserDatasources.stream()
                            .map(SysUserDatasource::getId)
                            .toArray(Long[]::new);

                    int i = sysUserDatasourceService.deleteSysUserDatasourceByIds(ageArray);

                }
            }


        }catch (Exception ex){
            logger.error("删除绑定数据信息异常："+ex.getMessage());
        }
    }
}
