package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.SysUserDatasource;
import com.ruoyi.system.service.ISysUserDatasourceService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 用户数据Controller
 *
 * @author wenjy
 * @date 2023-07-03
 */
@RestController
@RequestMapping("/userdatasource")
public class SysUserDatasourceController extends BaseController
{
    @Autowired
    private ISysUserDatasourceService sysUserDatasourceService;

    /**
     * 查询用户数据列表
     */
    @RequiresPermissions("system:userdatasource:list")
    @GetMapping("/list")
    public TableDataInfo list(SysUserDatasource sysUserDatasource)
    {
        startPage();
        List<SysUserDatasource> list = sysUserDatasourceService.selectSysUserDatasourceList(sysUserDatasource);
        return getDataTable(list);
    }

    /**
     * 导出用户数据列表
     */
    @RequiresPermissions("system:userdatasource:export")
    @Log(title = "用户数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysUserDatasource sysUserDatasource)
    {
        List<SysUserDatasource> list = sysUserDatasourceService.selectSysUserDatasourceList(sysUserDatasource);
        ExcelUtil<SysUserDatasource> util = new ExcelUtil<SysUserDatasource>(SysUserDatasource.class);
        util.exportExcel(response, list, "用户数据数据");
    }

    /**
     * 获取用户数据详细信息
     */
    @RequiresPermissions("system:userdatasource:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysUserDatasourceService.selectSysUserDatasourceById(id));
    }

    /**
     * 新增用户数据
     */
    @RequiresPermissions("system:userdatasource:add")
    @Log(title = "用户数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysUserDatasource sysUserDatasource)
    {
        return toAjax(sysUserDatasourceService.insertSysUserDatasource(sysUserDatasource));
    }

    /**
     * 修改用户数据
     */
    @RequiresPermissions("system:userdatasource:edit")
    @Log(title = "用户数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysUserDatasource sysUserDatasource)
    {
        return toAjax(sysUserDatasourceService.updateSysUserDatasource(sysUserDatasource));
    }

    /**
     * 删除用户数据
     */
    @RequiresPermissions("system:userdatasource:remove")
    @Log(title = "用户数据", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysUserDatasourceService.deleteSysUserDatasourceByIds(ids));
    }
}
